@@ -1,6 +1,6 @@
 package Padre::Plugin::SpellCheck;
 
-use v5.10;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ use Padre::Unload ();
 use File::Which   ();
 use Try::Tiny;
 
-our $VERSION = '1.29';
+our $VERSION = '1.32';
 use parent qw( Padre::Plugin );
 
 # Child modules we need to unload when disabled
@@ -44,7 +44,7 @@ sub padre_interfaces {
 		'Padre::Logger'         => '0.96',
 		'Padre::Wx'             => '0.96',
 		'Padre::Wx::Role::Main' => '0.96',
-		'Padre::Util'           => '0.96',
+		'Padre::Util'           => '0.97',
 	);
 }
 
@@ -241,24 +241,46 @@ sub spell_check {
 	return;
 }
 
+#######
+# Add icon to Plugin
+#######
+sub plugin_icon {
+	my $class = shift;
+	my $share = $class->plugin_directory_share or return;
+	my $file  = File::Spec->catfile( $share, 'icons', '16x16', 'spellcheck.png' );
+	return unless -f $file;
+	return unless -r $file;
+	return Wx::Bitmap->new( $file, Wx::wxBITMAP_TYPE_PNG );
+}
+
+#######
+# Add SpellCheck Preferences to Context Menu
+#######
+sub event_on_context_menu {
+	my ( $self, $document, $editor, $menu, $event ) = @_;
+
+	#Test for valid file type
+	return if not $document->filename;
+
+	$menu->AppendSeparator;
+
+	my $item = $menu->Append( -1, Wx::gettext('SpellCheck Preferences...') );
+	Wx::Event::EVT_MENU(
+		$self->main,
+		$item,
+		sub { $self->plugin_preferences },
+	);
+
+	return;
+}
+
 
 1;
 
 __END__
 
 # DO NOT REMOVE
-#######
-# Add icon to Plugin
-#######
-sub plugin_icon {
-		my $self = shift;
 
-		# find resource path
-		my $iconpath = catfile( $self->plugin_directory_share, 'icons', 'spellcheck.png' );
-
-		# create and return icon
-		return Wx::Bitmap->new( $iconpath, Wx::wxBITMAP_TYPE_PNG );
-}
 
 sub menu_plugins_simple {
 	my $self = shift;
@@ -268,6 +290,9 @@ sub menu_plugins_simple {
 	];
 }
 
+=pod
+
+=encoding utf8
 
 =head1 NAME
 
@@ -275,14 +300,17 @@ Padre::Plugin::SpellCheck - Check spelling in Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 1.29
+version: 1.32
 
 =head1 DESCRIPTION
 
-This plug-in allows one to check there spelling within Padre using
-C<F7> (standard spelling short-cut across text processors). 
+For Padre 0.98
 
-One can change the dictionary language used (based upon install languages) in the preferences window via Plug-in Manager. 
+This plug-in allows one to check there spelling within Padre using
+C<F7> (standard spelling short-cut across text processors).
+
+One can change the dictionary language used (based upon install languages) in
+ the preferences window via Plug-in Manager.
 Note that preferences can B<only> be setup while the plugin is B<disabled>.
 Preferences are persistent. You need to Save your preferred language.
 
@@ -325,7 +353,15 @@ Return the plug-in's configuration, or a suitable default one if none exist prev
 
 =item plugin_preferences()
 
-Open the check spelling preferences window.
+Spelling preferences window normally access via Plug-in Manager
+
+=item plugin_icon()
+
+Used by Plug-in Manager
+
+=item event_on_context_menu
+
+Add access to spelling preferences window.
 
 =back
 
@@ -343,9 +379,9 @@ Spell checks the current selection (or the whole document).
 
 =head1 BUGS and LIMITATIONS
 
-If you upgrade your os, and run Perl from a local/lib, 
-you may find Hunspell stops showing local dictionary s in preferences, 
-you will need to un-install Text::Hunspell and re-install in cpan.
+If you upgrade your OS, and run Perl from a local/lib,
+ you may find Hunspell stops showing local dictionary in preferences,
+ you will need to un-install Text::Hunspell and re-install in CPAN.
 
 
 Spell-checking non-ascii files has bugs: the selection does not
@@ -374,11 +410,11 @@ L<http://www.famfamfam.com/lab/icons/silk/>.
 
 L<http://padre.perlide.org/trac/wiki/PadrePluginSpellCheck>
 
-=item * Our svn repository 
+=item * Our svn repository
 
-L<http://svn.perlide.org/padre/trunk/Padre-Plugin-SpellCheck>, 
-and can be browsed at 
-L<http://padre.perlide.org/browser/trunk/Padre-Plugin-SpellCheck>.
+L<http://svn.perlide.org/padre/trunk/Padre-Plugin-SpellCheck>,
+ and can be browsed at
+ L<http://padre.perlide.org/browser/trunk/Padre-Plugin-SpellCheck>.
 
 =back
 
@@ -417,7 +453,8 @@ Jerome Quelin E<lt>jquelin@gmail.comE<gt>
 
 =head1 COPYRIGHT
 
-This software is copyright (c) 2010 by Fayland Lam, Jerome Quelin.
+This software is Copyright E<copy> 2010 by Fayland Lam, Jerome Quelin.
+Also Copyright E<copy> 2012-2013 AUTHORS and "CONTRIBUTORS" as listed above.
 
 =head1 LICENSE
 
@@ -426,7 +463,7 @@ modify it under the same terms as Perl 5 itself.
 
 =cut
 
-# Copyright 2008-2012 The Padre development team as listed in Padre.pm.
+# Copyright 2008-2013 The Padre development team as listed in Padre.pm.
 # LICENSE
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl 5 itself.
