@@ -4,17 +4,17 @@ use v5.10;
 use warnings;
 use strict;
 
-our $VERSION = '1.29';
+our $VERSION = '1.32';
 
 use Padre::Logger;
 use Padre::Unload ();
 
 use Class::Accessor 'antlers';
 has _ignore  => ( is => 'rw', isa => 'Str' ); # list of words to ignore
-has _speller => ( is => 'rw', isa => 'Str' ); # real text::aspell object
+has _speller => ( is => 'rw', isa => 'Str' ); # real text::Aspell object
 
 # FIXME: as soon as wxWidgets/wxPerl supports
-# newer version of STC:
+# newer version 1.31_03
 # number of UTF8 characters
 # used in calculating current possition
 has _utf_chars => ( is => 'rw', isa => 'Str' );
@@ -59,7 +59,7 @@ sub _init {
 		if ( exists $MIMETYPE_MODE{$mimetype} ) {
 			if ( not defined $speller->set_option( 'mode', $MIMETYPE_MODE{$mimetype} ) ) {
 				my $err = $speller->errstr;
-				warn "Could not set aspell mode '$MIMETYPE_MODE{$mimetype}': $err\n";
+				warn "Could not set Aspell mode '$MIMETYPE_MODE{$mimetype}': $err\n";
 			}
 		}
 
@@ -167,7 +167,7 @@ Padre::Plugin::SpellCheck::Engine - Check spelling in Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 1.29
+version: 1.32
 
 =head1 PUBLIC METHODS
 
@@ -198,10 +198,10 @@ Tell engine to ignore C<$word> for rest of the spell check.
 
 =item * my @dictionaries = $engine->dictionaries;
 
-Return a (reduced) list of dictionaries installed with aspell. The
-names returned are the dictionary locale names (eg C<en_US>). Note
+Return a (reduced) list of dictionaries installed with Aspell. The
+names returned are the dictionary locale names (e.g. C<en_US>). Note
 that only plain locales are reported, the variations coming with
-aspell are stripped.
+Aspell are stripped.
 
 =item * my @suggestions = $engine->get_suggestions( $word );
 
@@ -237,6 +237,7 @@ Jerome Quelin E<lt>jquelin@gmail.comE<gt>
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Fayland Lam, Jerome Quelin.
+Also Copyright E<copy> 2012-2013 AUTHORS and "CONTRIBUTORS" as listed above.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
